diff mbox series

[pynfs,08/10] st_flex: Only do 100 layoutget/return in loop

Message ID 20201217003516.75438-9-loghyr@hammerspace.com (mailing list archive)
State New, archived
Headers show
Series Misc Fixes, primarily LAYOUTRETURN | expand

Commit Message

Thomas Haynes Dec. 17, 2020, 12:35 a.m. UTC
Signed-off-by: Tom Haynes <loghyr@hammerspace.com>
---
 nfs4.1/server41tests/st_flex.py | 8 ++++----
 1 file changed, 4 insertions(+), 4 deletions(-)
diff mbox series

Patch

diff --git a/nfs4.1/server41tests/st_flex.py b/nfs4.1/server41tests/st_flex.py
index 63efdd2..596c75e 100644
--- a/nfs4.1/server41tests/st_flex.py
+++ b/nfs4.1/server41tests/st_flex.py
@@ -1074,16 +1074,16 @@  def testFlexLayoutReturnDelayWrite(t, env):
     res = close_file(sess, fh, stateid=open_stateid)
     check(res)
 
-def testFlexLayoutReturn1K(t, env):
+def testFlexLayoutReturn100(t, env):
     """
     Perform LAYOUTGET and LAYOUTRETURN 1K times with error being returned periodically
 
     FLAGS: flex layoutreturn
-    CODE: FFLOR1K
+    CODE: FFLOR100
     """
     name = env.testname(t)
     sess = env.c1.new_pnfs_client_session(env.testname(t))
-    count = 1000  # Repeat LAYOUTGET/LAYOUTRETURN count times
+    count = 100  # Repeat LAYOUTGET/LAYOUTRETURN count times
     layout_error_ratio = 10  # Send an error every layout_error_ratio layout returns
 
     # Create the file
@@ -1074,16 +1074,16 @@  def testFlexLayoutReturnDelayWrite(t, env):
     """
-    Perform LAYOUTGET and LAYOUTRETURN 1K times with error being returned periodically
+    Perform LAYOUTGET and LAYOUTRETURN 100 times with error being returned periodically
 
     FLAGS: flex layoutreturn